IF OBJECT_ID('[Scripts_Unified]') IS NOT NULL DROP VIEW [Scripts_Unified]
GO

CREATE VIEW [Scripts_Unified] AS

SELECT [UnifiedScript_Id] =	P.[Plan_Id],
       [UnifiedScript_Name] = P.[Plan_Name],
       [UnifiedScript_Version] = LATEST_VERSION.[PlanVersion_Id],
       [UnifiedScript_Type_Name] = 
			CASE 
				WHEN P.[PlanType_Code] = 'D' THEN 'Plan' 
				WHEN P.[PlanType_Code] = 'T' THEN 'Module'
				ELSE 'Other' 
			END,
	   P.[Application_Id],
       A.[Application_Name],
       P.[ModifiedOn_Date],
       P.[ModifiedBy_User_Name],
       P.[Environment_Id],
       E.[Environment_Name],
       P.[Active_Indicator]

  FROM [Plans] P

	    LEFT JOIN [Environments] E
               ON P.[Environment_Id] = E.[Environment_Id]
        LEFT JOIN [Applications] A
               ON P.[Application_Id] = A.[Application_Id]

		OUTER APPLY (
            SELECT TOP 1 * FROM [PlanVersions] PV WHERE PV.[Plan_Id] = P.[Plan_Id] ORDER BY PV.[PlanVersion_Id] DESC
        ) LATEST_VERSION

UNION ALL 

SELECT	[UnifiedScript_Id] = S.[ScriptAsset_Id],
		[UnifiedScript_Name] = S.[ScriptAsset_Name],
		[UnifiedScript_Version] = NULL,
		[UnifiedScript_Type_Name] = 
			CASE 
				WHEN S.[ScriptAsset_Name] LIKE '%.sh' THEN 'Shell'
				WHEN S.[ScriptAsset_Name] LIKE '%.ps1' THEN 'PowerShell' 
				ELSE 'Other' 
			END,
		S.[Application_Id],
		A.[Application_Name],
		S.[ModifiedOn_Date],
        S.[ModifiedBy_User_Name],
        [Environment_Id] = NULL,
        [Environment_Name] = NULL,
        [Active_Indicator] = 'Y'

	FROM [ScriptAssets] S

		LEFT JOIN [Applications] A
               ON S.[Application_Id] = A.[Application_Id]

GO