EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildMaster_GetAlerts',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Alerts_Xml',
    /* Description_Text        */ 'Gets the alerts.'
GO

IF OBJECT_ID('[BuildMaster_GetAlerts]') IS NOT NULL DROP PROCEDURE [BuildMaster_GetAlerts]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BuildMaster_GetAlerts]
(
	@Alerts_Xml XML = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

SET @Alerts_Xml =
    (SELECT
           [@IgnoreServiceWarning] = COALESCE((SELECT [Value_Text]
                                        FROM [Configuration]
										WITH (READUNCOMMITTED)
                                       WHERE [Key_Name] = 'Web.IgnoreServiceWarning'), 'False'),

           [@ErrorsInLog] = (CASE WHEN EXISTS(SELECT [LogMessage_Id]
                                                FROM [LogMessages]
												WITH (READUNCOMMITTED)
                                              WHERE [ShowNotification_Indicator] = 'Y')
                                         THEN 'True'
                                         ELSE 'False' END),

           [@ServersInErrorStatus] = (SELECT COUNT(*)
                                        FROM [Servers]
                                        WITH (READUNCOMMITTED)
                                       WHERE [ServerStatus_Code] = 'ERROR'
									     AND [ServerType_Code] = 'S'
                                         AND [Active_Indicator] = 'Y'),

           [@TotalServers] = (SELECT COUNT(*) 
                                        FROM [Servers] 
                                        WITH (READUNCOMMITTED)
                                       WHERE [ServerType_Code] = 'S'
                                         AND [Active_Indicator] = 'Y'),

           [@BmUpdateReminder] = (SELECT [Value_Text]
                                    FROM [Configuration]
									WITH (READUNCOMMITTED)
                                   WHERE [Key_Name] = 'System.SoftwareUpdateAvailable'),

           [@ExtUpdateReminder] = (SELECT [Value_Text]
                                     FROM [Configuration]
									 WITH (READUNCOMMITTED)
                                    WHERE [Key_Name] = 'Extensions.ShowReminder'),
       
           [ManualActionsInProgress] = (SELECT [@AssignedTo_Principal_Name] = [AssignedTo_Principal_Name]
                                FROM [ManualActionsInProgress]
							    WITH (READUNCOMMITTED)
                               WHERE [CompletedBy_User_Name] IS NULL
                                 FOR XML PATH('ManualAction'), TYPE),

		   [ExecutionsInProgress] = (SELECT [@ExecutionId] = X.[Execution_Id],
		                                    [@ApplicationId] = R.[Application_Id],
                                            [@EnvironmentId] = BE.[Environment_Id],
											[@ApplicationName] = A.[Application_Name],
											[@ReleaseName] = COALESCE(R.[Release_Name], R.[Release_Number]),
											[@PipelineStageName] = BP.[PipelineStage_Name]
		                               FROM [BuildExecutions] BE
									   WITH (READUNCOMMITTED)
									        INNER JOIN [Executions] X WITH (READUNCOMMITTED)
											       ON X.[Execution_Id] = BE.[Execution_Id]
											LEFT JOIN [BuildPromotions] BP WITH (READUNCOMMITTED)
											        ON BP.[Promotion_Id] = BE.[Promotion_Id]
											LEFT JOIN [Builds] B WITH (READUNCOMMITTED)
											        ON B.[Build_Id] = BP.[Build_Id]
											LEFT JOIN [Releases] R WITH (READUNCOMMITTED)
											        ON R.[Release_Id] = B.[Release_Id]
											LEFT JOIN [Applications] A WITH (READUNCOMMITTED)
											        ON A.[Application_Id] = R.[Application_Id]
									  WHERE X.[ExecutionRunState_Code] = 'X'
									    FOR XML PATH('Execution'), TYPE)

   FOR XML PATH('Alerts'))

END
GO

GRANT EXECUTE ON [BuildMaster_GetAlerts] TO [BuildMasterUser_Role]