EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildSchedules_CreateOrUpdateSchedule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Schedule_Id',
    /* Description_Text        */ 'Creates a scheduled build based on the specified parameters, or updates an existing scheduled build if one with the given ID already exists.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[BuildSchedules_CreateOrUpdateSchedule]') IS NOT NULL DROP PROCEDURE [BuildSchedules_CreateOrUpdateSchedule]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BuildSchedules_CreateOrUpdateSchedule]
(
	@Schedule_Id INT = NULL OUT,
	@Schedule_Name VARCHAR(100),
	@Application_Id INT,
    @Active_Indicator YNINDICATOR,
    @Schedule_Type VARCHAR(15),
	@StartTime_Minutes INT,
	@EndTime_Minutes SMALLINT,
	@DailyInterval_Minutes SMALLINT,
	@Recurrence_Type VARCHAR(10),
	@RecurrenceFrequency_Value INT,
	@RecurrenceWeeklyDay_Mask CHAR(7),
	@RecurrenceMonthlyDay_Value TINYINT,
	@RecurrenceMonthlyRelativity_Type VARCHAR(4),
    @RecurrenceMonthlyRelativityDay_Type VARCHAR(5),
    @RecurrenceMonthlyRelativityWeek_Type VARCHAR(7),
    @RecurrenceMonthlyRelativityWeekDay_Value TINYINT,
	@Url_AllowedIP_CSV varchar(MAX),
	@Url_Username_Text varchar(50),
	@Url_Password_Text varchar(50),
	@SourceControl_Path_Name varchar(250),
	@SourceControl_Provider_Id int,
	@SourceControl_QuietPeriod_Minutes INT,
	@ReleaseFilter_ReleaseType_Code CHAR(1),
	@ReleaseFilter_Pipeline_Id INT,
    @ReleaseFilter_Release_Number RELEASENUMBER
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Schedule_Id IS NULL
	BEGIN
		INSERT INTO [dbo].[BuildSchedules]
			([Schedule_Name]
			,[Application_Id]
			,[Active_Indicator]
			,[Schedule_Type]
			,[StartTime_Minutes]
			,[EndTime_Minutes]
			,[DailyInterval_Minutes]
			,[Recurrence_Type]
			,[RecurrenceFrequency_Value]
			,[RecurrenceWeeklyDay_Mask]
			,[RecurrenceMonthlyDay_Value]
			,[RecurrenceMonthlyRelativity_Type]
			,[RecurrenceMonthlyRelativityDay_Type]
			,[RecurrenceMonthlyRelativityWeek_Type]
			,[RecurrenceMonthlyRelativityWeekDay_Value]
			,[CreatedBy_User_Name]
			,[CreatedOn_Date]
			,[ModifiedBy_User_Name]
			,[ModifiedOn_Date]
			,[Url_AllowedIP_CSV]
			,[Url_Username_Text]
			,[Url_Password_Text]
			,[SourceControl_Path_Name]
			,[SourceControl_Provider_Id]
			,[SourceControl_QuietPeriod_Minutes]
			,[ReleaseFilter_ReleaseType_Code]
			,[ReleaseFilter_Pipeline_Id]
            ,[ReleaseFilter_Release_Number])
		VALUES
			(@Schedule_Name
			,@Application_Id
			,@Active_Indicator
			,@Schedule_Type
			,@StartTime_Minutes
			,@EndTime_Minutes
			,@DailyInterval_Minutes
			,@Recurrence_Type
			,@RecurrenceFrequency_Value
			,@RecurrenceWeeklyDay_Mask
			,@RecurrenceMonthlyDay_Value
			,@RecurrenceMonthlyRelativity_Type
			,@RecurrenceMonthlyRelativityDay_Type
			,@RecurrenceMonthlyRelativityWeek_Type
			,@RecurrenceMonthlyRelativityWeekDay_Value
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,@Url_AllowedIP_CSV
			,@Url_Username_Text
			,@Url_Password_Text
			,@SourceControl_Path_Name
			,@SourceControl_Provider_Id
			,@SourceControl_QuietPeriod_Minutes
			,@ReleaseFilter_ReleaseType_Code
			,@ReleaseFilter_Pipeline_Id
            ,@ReleaseFilter_Release_Number)

		SET @Schedule_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'BSHNEW',@Application_Id,@Schedule_Id

	END
	ELSE
	BEGIN
		UPDATE [dbo].[BuildSchedules]
		   SET [Schedule_Name] = @Schedule_Name
			  ,[Application_Id] = @Application_Id
			  ,[Active_Indicator] = @Active_Indicator
			  ,[Schedule_Type] = @Schedule_Type
			  ,[StartTime_Minutes] = @StartTime_Minutes
			  ,[EndTime_Minutes] = @EndTime_Minutes
			  ,[DailyInterval_Minutes] = @DailyInterval_Minutes
			  ,[Recurrence_Type] = @Recurrence_Type
			  ,[RecurrenceFrequency_Value] = @RecurrenceFrequency_Value
			  ,[RecurrenceWeeklyDay_Mask] = @RecurrenceWeeklyDay_Mask
			  ,[RecurrenceMonthlyDay_Value] = @RecurrenceMonthlyDay_Value
			  ,[RecurrenceMonthlyRelativity_Type] = @RecurrenceMonthlyRelativity_Type
			  ,[RecurrenceMonthlyRelativityDay_Type] = @RecurrenceMonthlyRelativityDay_Type
			  ,[RecurrenceMonthlyRelativityWeek_Type] = @RecurrenceMonthlyRelativityWeek_Type
			  ,[RecurrenceMonthlyRelativityWeekDay_Value] = @RecurrenceMonthlyRelativityWeekDay_Value
			  ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
			  ,[ModifiedOn_Date] = GETUTCDATE()
			  ,[Url_AllowedIP_CSV] = @Url_AllowedIP_CSV
			  ,[Url_Username_Text] = @Url_Username_Text
			  ,[Url_Password_Text] = @Url_Password_Text
			  ,[SourceControl_Path_Name] = @SourceControl_Path_Name
			  ,[SourceControl_Provider_Id] = @SourceControl_Provider_Id
			  ,[SourceControl_QuietPeriod_Minutes] = @SourceControl_QuietPeriod_Minutes
			  ,[ReleaseFilter_ReleaseType_Code] = @ReleaseFilter_ReleaseType_Code
			  ,[ReleaseFilter_Pipeline_Id] = @ReleaseFilter_Pipeline_Id
              ,[ReleaseFilter_Release_Number] = @ReleaseFilter_Release_Number
		 WHERE [Schedule_Id] = @Schedule_Id
		IF @@ROWCOUNT=0 RAISERROR('BuildSchedule #%i does not exist.',16,1,@Schedule_Id)

		EXEC [Events_RaiseEvent] 'BSHMOD',@Application_Id,@Schedule_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BuildSchedules_CreateOrUpdateSchedule] TO [BuildMasterUser_Role]
