EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_ImportBuildExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Execution_Id',
    /* Description_Text        */ 'Imports a build execution.'
GO

IF OBJECT_ID('[Builds_ImportBuildExecution]') IS NOT NULL DROP PROCEDURE [Builds_ImportBuildExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_ImportBuildExecution]
(
	@Start_Date DATETIME,
	@End_Date DATETIME,
	@ExecutionStatus_Code CHAR(1),
	@ExecutionRunState_Code CHAR(1),
	@CreatedBy_User_Name USERNAME,
	@CreatedOn_Date DATETIME,
	@CanceledBy_User_Name USERNAME,
	@CanceledOn_Date DATETIME,
	@Environment_Id INT,
	@Promotion_Id INT,
	@Plan_Name VARCHAR(255),
	@PipelineStageTarget_Index INT,
	@Execution_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Executions]
	(
		[Start_Date],
		[End_Date],
		[ExecutionStatus_Code],
		[ExecutionRunState_Code],
		[ExecutionMode_Code],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[CanceledBy_User_Name],
		[CanceledOn_Date]
	)
	VALUES
	(
		@Start_Date,
		@End_Date,
		@ExecutionStatus_Code,
		@ExecutionRunState_Code,
		'B',
		@CreatedBy_User_Name,
		@CreatedOn_Date,
		@CanceledBy_User_Name,
		@CanceledOn_Date
	)

	SET @Execution_Id = SCOPE_IDENTITY()

	INSERT INTO [BuildExecutions]
	(
		[Execution_Id],
		[Environment_Id],
		[Promotion_Id],
		[Plan_Name],
		[PipelineStageTarget_Index]
	)
	VALUES
	(
		@Execution_Id,
		@Environment_Id,
		@Promotion_Id,
		@Plan_Name,
		@PipelineStageTarget_Index
	)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
END
GO

GRANT EXECUTE ON [Builds_ImportBuildExecution] TO [BuildMasterUser_Role]
