EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PromoteBuild',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Promotion_Id',
    /* Description_Text        */ 'Promotes a build to to a pipeline stage.'
GO

IF OBJECT_ID('[Builds_PromoteBuild]') IS NOT NULL DROP PROCEDURE [Builds_PromoteBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PromoteBuild]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@Comments_Text VARCHAR(255),
	@ForcePromotion_Indicator YNINDICATOR,
	@PromoteTo_PipelineStage_Name VARCHAR(50),
	@SetFurthestStage_Indicator YNINDICATOR = NULL,
	@Promotion_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	SELECT @Build_Id = [Build_Id]
	  FROM [Builds_Extended]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number
	   AND [Build_Number] = @Build_Number

	INSERT INTO [BuildPromotions]
	(
		[Build_Id],
		[PipelineStage_Name],
		[PromotedBy_Name],
		[Comments_Text],
		[PromotionStatus_Name],
		[Forced_Indicator],
		[Promoted_Date]
	)
	VALUES
	(
		@Build_Id,
		@PromoteTo_PipelineStage_Name,
		dbo.Session_GetUserName(),
		NULLIF(@Comments_Text, ''),
		'AwaitingExecution',
		@ForcePromotion_Indicator,
		GETUTCDATE()
	)

	SET @Promotion_Id = SCOPE_IDENTITY()

	DELETE [BuildPromotionsScheduled]
	 WHERE [Build_Id] = @Build_Id
	   AND [PipelineStage_Name] = @PromoteTo_PipelineStage_Name

	IF @SetFurthestStage_Indicator = 'Y'
	BEGIN

		UPDATE [Builds]
		   SET [Furthest_PipelineStage_Name] = @PromoteTo_PipelineStage_Name
		 WHERE [Build_Id] = @Build_Id

	END

	EXEC [Events_RaiseEvent] 'BLDPMT', @Application_Id, @Release_Number, @Build_Number, @PromoteTo_PipelineStage_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
		   
END
GO

GRANT EXECUTE ON [Builds_PromoteBuild] TO [BuildMasterUser_Role]
