EXEC [__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Issues_UpdateIssue',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates one or more properties of an issue.'
GO

IF OBJECT_ID('[Issues_UpdateIssue]') IS NOT NULL DROP PROCEDURE [Issues_UpdateIssue]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Issues_UpdateIssue]
(
	@Application_Id INT,
	@Issue_Id INT,
	@Release_Number RELEASENUMBER,
    @Type_Text NVARCHAR(50) = NULL,
	@Title_Text NVARCHAR(200) = NULL,
	@Description_Text NVARCHAR(MAX) = NULL,
    @Closed_Indicator YNINDICATOR = NULL,
	@IssueTracker_IssueStatus_Text NVARCHAR(100) = NULL,
    @IssueTracker_IssueUrl_Text NVARCHAR(255) = NULL,
	@IssueTracker_LastSync_Date DATETIME = NULL,
    @OpenedOn_Original_Build_Number BUILDNUMBER = NULL,
    @ClosedOn_Original_Build_Number BUILDNUMBER = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Release_Id INT
	SELECT @Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

	UPDATE [Issues]
	   SET [Release_Id] = @Release_Id,
           [Type_Text] = NULLIF(COALESCE(@Type_Text, [Type_Text]), ''),
	       [Title_Text] = COALESCE(@Title_Text, [Title_Text]),
		   [Description_Text] = COALESCE(@Description_Text, [Description_Text]),
           [Closed_Indicator] = COALESCE(@Closed_Indicator, [Closed_Indicator]),
		   [IssueTracker_IssueStatus_Text] = COALESCE(@IssueTracker_IssueStatus_Text, [IssueTracker_IssueStatus_Text]),
           [IssueTracker_IssueUrl_Text] = COALESCE(@IssueTracker_IssueUrl_Text, [IssueTracker_IssueUrl_Text]),
		   [IssueTracker_LastSync_Date] = COALESCE(@IssueTracker_LastSync_Date, [IssueTracker_LastSync_Date]),
           [OpenedOn_Original_Build_Number] = NULLIF(COALESCE(@OpenedOn_Original_Build_Number, [OpenedOn_Original_Build_Number]), ''),
           [ClosedOn_Original_Build_Number] = NULLIF(COALESCE(@ClosedOn_Original_Build_Number, [ClosedOn_Original_Build_Number]), '')
	 WHERE [Application_Id] = @Application_Id
	   AND [Issue_Id] = @Issue_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Issues_UpdateIssue] TO [BuildMasterUser_Role]
