EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Pipelines_CreatePipeline',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Pipeline_Id',
    /* Description_Text        */ 'Creates a new pipeline.'
GO

IF OBJECT_ID('[Pipelines_CreatePipeline]') IS NOT NULL DROP PROCEDURE [Pipelines_CreatePipeline]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Pipelines_CreatePipeline]
(
	@Pipeline_Name VARCHAR(255),
    @Pipeline_Configuration XML,
    @Active_Indicator YNINDICATOR,
    @Application_Id INT,
	@Pipeline_Color VARCHAR(20),
	@ModifiedBy_User_Name USERNAME = NULL,
	@ModifiedOn_Date DATETIME = NULL,
	@Pipeline_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Pipelines]
	(
        [Pipeline_Name],
        [Application_Id],
        [Pipeline_Configuration],
        [Active_Indicator],
        [ModifiedOn_Date],
        [ModifiedBy_User_Name],
		[Pipeline_Color]
	)
	VALUES
	(
        @Pipeline_Name,
        @Application_Id,
        @Pipeline_Configuration,
        @Active_Indicator,
        COALESCE(@ModifiedOn_Date, GETUTCDATE()),
        COALESCE(@ModifiedBy_User_Name, dbo.Session_GetUserName()),
		@Pipeline_Color
	)

	SET @Pipeline_Id = SCOPE_IDENTITY()

	--EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @Pipeline_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Pipelines_CreatePipeline] TO [BuildMasterUser_Role]
