EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_CreateOrUpdateReleaseTargetDate',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ReleaseTargetDate_Id',
    /* Description_Text        */ 'Creates a new release target date, or updates an existing one.'
GO

IF OBJECT_ID('[Releases_CreateOrUpdateReleaseTargetDate]') IS NOT NULL DROP PROCEDURE [Releases_CreateOrUpdateReleaseTargetDate]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_CreateOrUpdateReleaseTargetDate]
(
	@Release_Id INT,
	@Target_Name NVARCHAR(50),
    @Start_Date DATETIME,
    @End_Date DATETIME,
    @ReleaseTargetDate_Id INT = NULL OUT
) 
AS BEGIN

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

	IF @ReleaseTargetDate_Id IS NOT NULL

		UPDATE [ReleaseTargetDates]
		   SET [Target_Name] = @Target_Name,
               [Start_Date] = @Start_Date,
               [End_Date] = @End_Date
		 WHERE [ReleaseTargetDate_Id] = @ReleaseTargetDate_Id
	
	ELSE BEGIN

		INSERT INTO [ReleaseTargetDates]
		(
			[Release_Id],
			[Target_Name],
            [Start_Date],
            [End_Date]
		)
		VALUES
		(
			@Release_Id,
			@Target_Name,
            @Start_Date,
            @End_Date
		)

        SET @ReleaseTargetDate_Id = SCOPE_IDENTITY()
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0  ROLLBACK
	EXEC [HandleError]
END CATCH
		 
END
GO

GRANT EXECUTE ON [Releases_CreateOrUpdateReleaseTargetDate] TO [BuildMasterUser_Role]
