EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_ReleaseExists',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ReleaseExists_Indicator,NewerDeployedReleaseExists_Indicator',
    /* Description_Text        */ 'Determines whether a release already exists, and also whether a newer release of an application exists'
GO

IF OBJECT_ID('[Releases_ReleaseExists]') IS NOT NULL DROP PROCEDURE [Releases_ReleaseExists]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_ReleaseExists]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@ReleaseExists_Indicator YNINDICATOR = NULL OUT,
	@NewerDeployedReleaseExists_Indicator YNINDICATOR = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

    DECLARE @Release_Id INT

	SET @ReleaseExists_Indicator =
		CASE WHEN EXISTS(SELECT *
						   FROM [Releases]
						  WHERE [Release_Number] = @Release_Number
							AND [Application_Id] = @Application_Id)
			 THEN 'Y'
			 ELSE 'N' END

    DECLARE @Release_Sequence BIGINT

    SELECT @Release_Sequence = [Release_Sequence]
     FROM [Releases]
    WHERE [Application_Id] = @Application_Id 
      AND [Release_Number] = @Release_Number

	SET @NewerDeployedReleaseExists_Indicator =
		CASE WHEN EXISTS(SELECT *
						   FROM [Releases]
						  WHERE [Release_Sequence] > @Release_Sequence
							AND [Application_Id] = @Application_Id
							AND [ReleaseStatus_Name] = 'Deployed')
			 THEN 'Y'
			 ELSE 'N' END

END
GO

GRANT EXECUTE ON [Releases_ReleaseExists] TO [BuildMasterUser_Role]