EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Scripts_CreateOrUpdateScript',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Script_Id',
    /* Description_Text        */ 'Creates a new script or updates an existing one.'
GO


IF OBJECT_ID('[Scripts_CreateOrUpdateScript]') IS NOT NULL DROP PROCEDURE [Scripts_CreateOrUpdateScript]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Scripts_CreateOrUpdateScript]
(
	@Script_Id INT OUT,
	@Script_Name NVARCHAR(50),
	@Description_Text NVARCHAR(MAX),
	@ScriptType_Code VARCHAR(20),
	@Active_Indicator YNINDICATOR,
	@AutoSync_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Script_Id IS NULL
	BEGIN

		INSERT INTO [Scripts]
		(
			[Script_Name],
			[Description_Text],
			[Active_Indicator],
			[AutoSync_Indicator],
			[ScriptType_Code],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@Script_Name,
			@Description_Text,
			@Active_Indicator,
			@AutoSync_Indicator,
			@ScriptType_Code,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)

		SET @Script_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [Scripts]
		   SET [Script_Name] = @Script_Name,
		       [Description_Text] = @Description_Text,
		       [ScriptType_Code] = @ScriptType_Code,
		       [Active_Indicator] = @Active_Indicator,
		       [AutoSync_Indicator] = @AutoSync_Indicator,
		       [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
		       [ModifiedOn_Date] = GETUTCDATE()
		 WHERE [Script_Id] = @Script_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Scripts_CreateOrUpdateScript] TO [BuildMasterUser_Role]