EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Servers_CreateOrUpdateServer',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Server_Id',
    /* Description_Text        */ 'Creates a new server, or updates an existing one.'
GO


IF OBJECT_ID('[Servers_CreateOrUpdateServer]') IS NOT NULL DROP PROCEDURE [Servers_CreateOrUpdateServer]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Servers_CreateOrUpdateServer]
(
	@Server_Name VARCHAR(50),
	@Agent_Configuration VARCHAR(MAX) = NULL,
	@Active_Indicator YNINDICATOR = NULL,
    @ServerType_Code CHAR(1) = NULL,
    @Restricted_Indicator YNINDICATOR = NULL,
	@EnvironmentIds_Csv VARCHAR(MAX) = NULL,
	@ServerIdsInGroup_Csv VARCHAR(MAX) = NULL,
    @ServerRoleIds_Csv VARCHAR(MAX) = NULL,
    @LogServerErrors_Indicator YNINDICATOR = NULL,
    @Server_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Server_Id IS NULL)
		BEGIN
			INSERT INTO [Servers] 
				(
					[Server_Name],
					[CreatedBy_User_Name],
					[CreatedOn_Date],
					[ModifiedBy_User_Name],
					[ModifiedOn_Date],
					[ServerType_Code],
					[Agent_Configuration],
					[ServerStatus_Code],
					[Active_Indicator],
                    [LogServerErrors_Indicator],
                    [Restricted_Indicator]
				)
			VALUES
				(
					@Server_Name,
					dbo.Session_GetUserName(),
					GETUTCDATE(),
					dbo.Session_GetUserName(),
					GETUTCDATE(),
					COALESCE(@ServerType_Code, 'S'),
					@Agent_Configuration,
					'UNKWN',
					@Active_Indicator,
                    COALESCE(@LogServerErrors_Indicator, 'Y'),
                    COALESCE(@Restricted_Indicator, 'N')
				)
			SET @Server_Id = SCOPE_IDENTITY()

			EXEC [Events_RaiseEvent] 'ENVNWS', NULL, @Server_Id
		END

	ELSE
		BEGIN
			UPDATE [Servers]
			   SET [Server_Name] = @Server_Name,
				   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
				   [ModifiedOn_Date] = GETUTCDATE(),
				   [ServerType_Code] = COALESCE(@ServerType_Code, [ServerType_Code]),
				   [Agent_Configuration] = COALESCE(@Agent_Configuration, [Agent_Configuration]),
				   [Active_Indicator] = COALESCE(@Active_Indicator, [Active_Indicator]),
                   [LogServerErrors_Indicator] = COALESCE(@LogServerErrors_Indicator, [LogServerErrors_Indicator]),
                   [Restricted_Indicator] = COALESCE(@Restricted_Indicator, [Restricted_Indicator])
			 WHERE [Server_Id] = @Server_Id

			EXEC [Events_RaiseEvent] 'ENVMDS', NULL, @Server_Id
		END

	IF (@EnvironmentIds_Csv IS NOT NULL) BEGIN
		DELETE [EnvironmentServers] WHERE [Server_Id] = @Server_Id
		INSERT [EnvironmentServers] ([Server_Id], [Environment_Id])
		SELECT @Server_Id, [Value_Text] FROM dbo.CsvToTable(@EnvironmentIds_Csv, ',')
	END

	IF (@ServerIdsInGroup_Csv IS NOT NULL) BEGIN
		DELETE [ServerGroups] WHERE [ServerGroup_Server_Id] = @Server_Id
		INSERT [ServerGroups] ([ServerGroup_Server_Id], [Server_Id])
		SELECT @Server_Id, [Value_Text] FROM dbo.CsvToTable(@ServerIdsInGroup_Csv, ',')
	END

    IF (@ServerRoleIds_Csv IS NOT NULL) BEGIN
		DELETE [ServerRoleServers] WHERE [Server_Id] = @Server_Id
		INSERT [ServerRoleServers] ([Server_Id], [ServerRole_Id])
		SELECT @Server_Id, [Value_Text] FROM dbo.CsvToTable(@ServerRoleIds_Csv, ',')
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Servers_CreateOrUpdateServer] TO [BuildMasterUser_Role]
